@@ -69,7 +69,8 @@ extern String FileStem;
 
 extern Tree *Raw, *Pruned, WTree;
 
-extern float Confidence, SampleFrac, *Vote, *BVoteBlock, **MCost, **NCost,
+extern double Confidence; // as in global.c
+extern float SampleFrac, *Vote, *BVoteBlock, **MCost, **NCost,
     *WeightMul;
 
 extern CRule *MostSpec;
@@ -84,7 +85,7 @@ extern double *ClassFreq, **DFreq;
 
 extern float *Gain, *Info, *EstMaxGR;
 
-double *ClassSum;
+extern double *ClassSum;
 
 extern ContValue *Bar;
 
